import rclpy
from rclpy.node import Node
from std_msgs.msg import Float32
from behavior_interface.msg import BehaviorStatus

class AlignCorridor(Node):
    def __init__(self):
        super().__init__('AlignCorridor')
        self.align_publisher = self.create_publisher(Float32, '/angular_z', 10)
        self.status_publisher = self.create_publisher(BehaviorStatus, '/behavior_status', 10)
        self.angle_ratio_subscriber = self.create_subscription(Float32, '/vp_angle_ratio', self.on_angle_ratio, 10)
        
    def on_angle_ratio(self, msg):
        align_command = Float32(data=msg.data * 0.5)  
        self.align_publisher.publish(align_command)

        status_msg = BehaviorStatus()
        status_msg.name = "AlignCorridor"
        status_msg.status = True
        self.status_publisher.publish(status_msg)

        self.get_logger().info(f"Aligning with corridor, angular_z set to {align_command.data}")

def main(args=None):
    rclpy.init(args=args)
    align_corridor = AlignCorridor()
    rclpy.spin(align_corridor)
    align_corridor.destroy_node()
    rclpy.shutdown()

if __name__ == '__main__':
    main()
