import rclpy
from rclpy.node import Node
from std_msgs.msg import Float32
from behavior_interface.msg import BehaviorStatus

class CenterCorridor(Node):
    def __init__(self):
        super().__init__('CenterCorridor')
        self.center_publisher = self.create_publisher(Float32, '/linear_y', 10)
        self.status_publisher = self.create_publisher(BehaviorStatus, '/behavior_status', 10)
        self.vp_offset_subscriber = self.create_subscription(Float32, '/vp_horizontal_offset', self.on_vp_offset, 10)

    def on_vp_offset(self, msg):
        center_command = Float32(data=msg.data * 0.2)  
        self.center_publisher.publish(center_command)

        status_msg = BehaviorStatus()
        status_msg.name = "CenterCorridor"
        status_msg.status = True
        self.status_publisher.publish(status_msg)

        self.get_logger().info(f"Centering in corridor, linear_y set to {center_command.data}")

def main(args=None):
    rclpy.init(args=args)
    center_corridor = CenterCorridor()
    rclpy.spin(center_corridor)
    center_corridor.destroy_node()
    rclpy.shutdown()

if __name__ == '__main__':
    main()
