from .auto_off import AutoOffBehavior
from std_msgs.msg import Empty
from behavior_interface.msg import BehaviorStatus
import rclpy

class Hover(AutoOffBehavior):
    def __init__(self):
        super().__init__('Hover', off_duration=2.0)
        self.hover_publisher = self.create_publisher(Empty, '/bebop/hover', 10)
        self.status_publisher = self.create_publisher(BehaviorStatus, 'behaviors_status', 10)

    def on_status(self):

        if self.status:
            self.get_logger().info("Hover behavior activated")
            self.hover_publisher.publish(Empty())
        else:
            self.get_logger().info("Hover behavior deactivated")
        self.publish_behavior_status()

    def publish_behavior_status(self):
        status_msg = BehaviorStatus()
        status_msg.name = self.name
        status_msg.status = self.status
        self.status_publisher.publish(status_msg)

def main(args=None):
    rclpy.init(args=args)
    hover_behavior = Hover()
    rclpy.spin(hover_behavior)
    hover_behavior.destroy_node()
    rclpy.shutdown()

if __name__ == '__main__':
    main()

