import rclpy
from rclpy.node import Node
from std_msgs.msg import Float32
from behavior_interface.msg import BehaviorStatus  

class MoveForwardVp(Node):
    def __init__(self):
        super().__init__('MoveForwardVp')
        self.forward_publisher = self.create_publisher(Float32, '/linear_x', 10)
        self.status_publisher = self.create_publisher(BehaviorStatus, '/behavior_status', 10)
        self.vp_offset_subscriber = self.create_subscription(Float32, '/vp_horizontal_offset', self.on_vp_offset, 10)
        
    def on_vp_offset(self, msg):
        status_msg = BehaviorStatus()
        status_msg.name = "MoveForwardVp"
        if abs(msg.data) < 10: 
            self.forward_publisher.publish(Float32(data=0.5))  
            status_msg.status = True
            self.get_logger().info("Moving forward")
        else:
            self.forward_publisher.publish(Float32(data=0.0))  
            status_msg.status = False
            self.get_logger().info("Stopping movement")

        self.status_publisher.publish(status_msg)

def main(args=None):
    rclpy.init(args=args)
    move_forward_vp = MoveForwardVp()
    rclpy.spin(move_forward_vp)
    move_forward_vp.destroy_node()
    rclpy.shutdown()

if __name__ == '__main__':
    main()

