import rclpy
from .base_behavior import BaseBehavior
from geometry_msgs.msg import Twist
from nav_msgs.msg import Odometry

import numpy as np

import sympy
from sympy.algebras.quaternion import Quaternion
from sympy import symbols
from sympy import conjugate

class Slide_Node(BaseBehavior):
    def __init__(self, name):
        super().__init__(name)
        self.current_velocity = Twist()
        self.qx = None
        self.qy = None
        self.qz = None
        self.qw = None
        self.x = None
        self.y = None
        self.OP_0 = None
        self.OD = None
        self.pub = self.create_publisher(Twist, '/bebop/cmd_vel', 10)
        self.sub_odom = self.create_subscription(Odometry, '/odom', self.on_odom, 10)
    

    def on_odom(self, msg):
        self.current_velocity = msg.twist.twist
        orientation = msg.pose.pose.orientation
        self.qx = orientation.x
        self.qy = orientation.y
        self.qz = orientation.z
        self.qw = orientation.w
        
        x = msg.pose.pose.position.x
        y = msg.pose.pose.position.y
        self.OD = np.array([x, y])

        if self.OP_0 == None:
            self.OP_0 = np.array([x, y])


    def on_status(self, msg):
        super().on_status(msg)
        self.open_loop()
        self.closed_loop()
    

    def open_loop(self):
        t0 = self.get_clock().now()
        twist = Twist()
        while True:
            if (self.get_clock().now() - t0).nanoseconds*10**(-9) < 1:
                twist.angular.z = 3
            twist.linear.y = 0.2
            self.pub.publish(twist)
    

    def closed_loop(self):
        q1 = Quaternion(self.qw, self.qx, self.qy, self.qz, real_field=True)
        forward = Quaternion(0, 1, 0, 0)
        res = q1 * forward * conjugate(q1)
        horizontal_res_normalized = Quaternion(res.a, res.b, res.c, 0.0).normalize()
        vx, vy = horizontal_res_normalized.b, horizontal_res_normalized.c
        vect = np.array([vx, vy])
        PD = (np.eye(2)-np.outer(vect, vect))@(self.OD - self.OP_0)
        dist = np.sign(np.dot(PD,forward))*np.linalg.norm(PD)
        n = PD/np.linalg.norm(PD)
        tetha = np.arctan2(np.cross(n,horizontal_res_normalized),np.dot(n,horizontal_res_normalized))

        twist = Twist()
        twist.angular.z = tetha/2
        twist.linear.x = dist

        self.pub.publish(twist)




        

def main(args=None):
    rclpy.init(args=args)

    Slide = Slide_Node('Slide')
    rclpy.spin(Slide)

    Slide.destroy_node()
    rclpy.shutdown()

if __name__=='__main__':
    main()