import rclpy
from rclpy.node import Node
from behavior_interface.msg import BehaviorStatus

class BaseBehavior(Node):
    def __init__(self, name):
        super().__init__('base_behavior_' + name)
        self.name = name
        self.status = False  
        self.status_publisher = self.create_publisher(BehaviorStatus, 'behaviors_status', 10)

        self.subscription = self.create_subscription(
            BehaviorStatus,
            'behavior',
            self.listener_callback,
            10
        )
        self.get_logger().info(f'{self.name} behavior node initialized')

    def listener_callback(self, msg):
        if msg.name == self.name:
            if self.status != msg.status:
                self.status = msg.status
                self.on_status()

    def publish_status(self):
        status_msg = BehaviorStatus()
        status_msg.name = self.name
        status_msg.status = self.status
        self.status_publisher.publish(status_msg)
        self.get_logger().info(f"Published status: {self.name} - {self.status}")

    def on_status(self):
        self.publish_status()

