#!/usr/bin/env python

import rclpy
from rclpy.node import Node
from sensor_msgs.msg import CompressedImage
import cv2
from cv_bridge import CvBridge
from low_level.twisttopic_node import Twist2Pic  # 确保正确导入 Twist2Pic

class ViewerNode(Twist2Pic):
    def __init__(self):
        super().__init__()  # 只调用无参数的 __init__()
        
        # 初始化 CvBridge 以进行图像转换
        self.bridge = CvBridge()
        
        # 创建订阅者以接收压缩图像
        self.sub_image = self.create_subscription(
            CompressedImage,
            '/image_out/compressed',  # twist2pic 节点发布的主题
            self.on_image,
            qos_profile=1
        )

    def on_image(self, msg):
        # 将 ROS 图像消息转换为 OpenCV 图像
        frame = self.bridge.compressed_imgmsg_to_cv2(msg, 'bgr8')

        # 使用 OpenCV 显示图像
        cv2.imshow("Viewer Node - Image", frame)
        cv2.waitKey(1)  # 刷新显示

def main(args=None):
    rclpy.init(args=args)
    
    viewer_node = ViewerNode()
    rclpy.spin(viewer_node)  # 保持节点活动状态以接收消息

    # 关闭节点和 OpenCV 窗口
    viewer_node.destroy_node()
    rclpy.shutdown()
    cv2.destroyAllWindows()

if __name__ == "__main__":
    main()
